@@ -21,15 +21,15 @@
 #include "../cross_process_sync.h"
 #include "../fork_and_run.h"
 
-#include <com/ubuntu/content/hub.h>
-#include <com/ubuntu/content/peer.h>
-#include <com/ubuntu/content/scope.h>
-#include <com/ubuntu/content/store.h>
-#include <com/ubuntu/content/type.h>
+#include <com/lomiri/content/hub.h>
+#include <com/lomiri/content/peer.h>
+#include <com/lomiri/content/scope.h>
+#include <com/lomiri/content/store.h>
+#include <com/lomiri/content/type.h>
 
-#include "com/ubuntu/content/detail/peer_registry.h"
-#include "com/ubuntu/content/detail/service.h"
-#include "com/ubuntu/content/serviceadaptor.h"
+#include "com/lomiri/content/detail/peer_registry.h"
+#include "com/lomiri/content/detail/service.h"
+#include "com/lomiri/content/serviceadaptor.h"
 
 #include <gmock/gmock.h>
 #include <gtest/gtest.h>
@@ -41,9 +41,9 @@
 
 #include <thread>
 
-namespace cua = com::ubuntu::ApplicationManager;
-namespace cuc = com::ubuntu::content;
-namespace cucd = com::ubuntu::content::detail;
+namespace cua = com::lomiri::ApplicationManager;
+namespace cuc = com::lomiri::content;
+namespace cucd = com::lomiri::content::detail;
 
 void PrintTo(const QString& s, ::std::ostream* os) {
     *os << std::string(qPrintable(s));
@@ -51,7 +51,7 @@ void PrintTo(const QString& s, ::std::ostream* os) {
 
 namespace
 {
-QString service_name{"com.ubuntu.content.dbus.Service"};
+QString service_name{"com.lomiri.content.dbus.Service"};
 
 struct MockedPeerRegistry : public cucd::PeerRegistry
 {
@@ -91,20 +91,21 @@ TEST(Hub, stores_are_reported_correctly_to_clients)
 
         QSharedPointer<cucd::PeerRegistry> registry{new MockedPeerRegistry{}};
         auto app_manager = QSharedPointer<cua::ApplicationManager>(new MockedAppManager());
-        auto implementation = new cucd::Service(connection, registry, app_manager, &app);
-        new ServiceAdaptor(implementation);
+        cucd::Service implementation(connection, registry, app_manager, &app);
+        new ServiceAdaptor(std::addressof(implementation));
 
-        ASSERT_TRUE(connection.registerService(service_name));
-        ASSERT_TRUE(connection.registerObject("/", implementation));
+        connection.registerService(service_name);
+        connection.registerObject("/", std::addressof(implementation));
 
-        sync.signal_ready();
+        QObject::connect(&app, &QCoreApplication::aboutToQuit, [&](){
+            connection.unregisterObject("/");
+            connection.unregisterService(service_name);
+        });
+
+        // Make sure we signal readiness after the event loop has started.
+        QTimer::singleShot(0 /* msec */, [&sync]() { sync.signal_ready(); });
 
         app.exec();
-
-        connection.unregisterObject("/");
-        connection.unregisterService(service_name);
-
-        delete implementation;
     };
 
     auto child = [&sync]()
@@ -149,6 +150,8 @@ TEST(Hub, stores_are_reported_correctly_to_clients)
             hub->quit();
         });
         EXPECT_EQ(0, QTest::qExec(std::addressof(harness)));
+
+        return testing::Test::HasFailure();
     };
     
     EXPECT_EQ(EXIT_SUCCESS, test::fork_and_run(child, parent));
